package com.iguanaui.columnseries;

import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

import com.iguanaui.controls.DataChart;
import com.iguanaui.controls.Series;
import com.iguanaui.controls.axes.CategoryAxis;
import com.iguanaui.controls.axes.CategoryXAxis;
import com.iguanaui.controls.axes.NumericAxis;
import com.iguanaui.controls.axes.NumericYAxis;
import com.iguanaui.controls.valuecategory.ColumnSeries;
import com.iguanaui.controls.valuecategory.ValueCategorySeries;

public class ColumnSeriesActivity extends Activity {
	private void createData() {
        Random random=new Random();
        float value1=25.0f;
        float value2=25.0f;
        
        for(int i=0; i<20; ++i) {
        	value1+=2.0*(random.nextFloat()-0.5f);
        	value2+=2.0*(random.nextFloat()-0.5f);
        	
        	categories.add(Integer.toString(i));
        	column1.add(value1);
        	column2.add(value2);
        }		
	}
	private void updateData() {
        Random random=new Random();
        float value1=25.0f;
        float value2=25.0f;
        
        for(int i=0; i<categories.size(); ++i) {
        	value1+=2.0*(random.nextFloat()-0.5f);
        	value2+=2.0*(random.nextFloat()-0.5f);
        	
        	column1.set(i, value1);
        	column2.set(i, value2);
        }
	}

	private void createChart() {
		dataChart=(DataChart)findViewById(R.id.dataChart);	// get the empty chart view from the activity layout
        dataChart.setHorizontalZoomEnabled(true);			// allow horizontal zooming
        dataChart.setVerticalZoomEnabled(false);			// don't allow vertical zooming

        // set up an x axis
        
        CategoryXAxis categoryAxis=new CategoryXAxis(); 
        categoryAxis.setDataSource(categories);			// tell the axis about the data table
        categoryAxis.setLabelFormatter(new CategoryAxis.LabelFormatter() {
			public String format(CategoryAxis axis, Object item) {
				return (String)item;						// return the axis item as a string
			}
		});
        dataChart.scales().add(categoryAxis);				// all axes must be added to the chart's scales collection
     
        // set up a y axis
        
        NumericYAxis valueAxis=new NumericYAxis();
        valueAxis.setMinimumValue(0.0f);					// the random data look much nicer with a fixed axis range
        valueAxis.setMaximumValue(50.0f);					// the random data look much nicer with a fixed axis range
        valueAxis.setLabelFormatter(new NumericAxis.LabelFormatter() {
			public String format(NumericAxis axis, float item, int precision) {
				if(precision!=numberFormat.getMinimumFractionDigits()) {
					numberFormat.setMinimumFractionDigits(precision);	// set the formatting precision
					numberFormat.setMaximumFractionDigits(precision);	// set the formatting precision
				}
				
				return numberFormat.format(item);						// return item as a string
			}
        
        	final NumberFormat numberFormat=NumberFormat.getInstance();	// numeric formatter for axis values
        });
        dataChart.scales().add(valueAxis);					// all axes must be added to the chart's scales collection
 
        {
	        ValueCategorySeries series=new ColumnSeries();	
	        series.setCategoryAxis(categoryAxis);			// tell the series its x axis
	        series.setValueAxis(valueAxis);					// tell the series its y axis
	        series.setValueMember("");						// tell the series the data rows are the values
	        series.setDataSource(column1);					// tell the series the data table
	        
	        dataChart.series().add(series);					// add the series to the chart
        }
        
        {
	        ValueCategorySeries series=new ColumnSeries();	
	        series.setCategoryAxis(categoryAxis);			// tell the series its x axis
	        series.setValueAxis(valueAxis);					// tell the series its y axis
	        series.setValueMember("");						// tell the series the data rows are the values
	        series.setDataSource(column2);					// tell the series the data table
	        
	        dataChart.series().add(series);					// add the series to the chart
        }
	}
	private void createUI() {
        Button updateButton=(Button)findViewById(R.id.updateButton);
        
        updateButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				updateData();

				for(Series series: dataChart.series()) {
					series.notifyDataReset();
				}
			}
		});
        
        Button overlapButton=(Button)findViewById(R.id.overlapButton);
        
        overlapButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				CategoryXAxis categoryAxis=(CategoryXAxis)dataChart.scales().get(0);

				categoryAxis.setOverlap(2.0f*new Random().nextFloat()-1.0f);
			}
		});
        
        Button gapButton=(Button)findViewById(R.id.gapButton);
        
        gapButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				CategoryXAxis categoryAxis=(CategoryXAxis)dataChart.scales().get(0);

				categoryAxis.setGap(new Random().nextFloat());
			}
		});
	}
	
	private DataChart dataChart;
	private List<String> categories=new ArrayList<String>();
	private List<Float> column1=new ArrayList<Float>();
	private List<Float> column2=new ArrayList<Float>();
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        createData();
        
        
        createChart();
        createUI();
    }
}